/*
 *  laus helper functions used throughout shadow-utils
 *
 *  Copyright (C) 2004, Red Hat, Inc.
 *
 *  Redistributable under the same terms as the other elements of
 *  shadow-utils v4.0.3.
 */

#include <config.h>

#ifdef HAVE_LIBLAUS
#include <stdlib.h>
#include <syslog.h>
#include <stdarg.h>
#include <laus.h>
int __laus_active;
#endif

static void
laus_help_errmsg( const char *f, int x )
{
#ifdef HAVE_LIBLAUS
	if( !__laus_active) {
		return;
	}
	syslog(LOG_WARNING,
	       "LAuS error - %s:%i - %s: (%i) %s\n",
	       __FILE__, __LINE__,
	       f, x, laus_strerror(x));

#endif
}

void
laus_help_open(void)
{
#ifdef HAVE_LIBLAUS
        int rc = laus_open(NULL);
        if (rc < 0)
        {
                laus_help_errmsg("laus_open", errno);
                __laus_active = 0;
        } else {
                __laus_active = 1;
	}
#endif
}

void
laus_help_log( const char *tag, const char *fmt, ...)
{
#ifdef HAVE_LIBLAUS

	char	       	buffer[8*1024] = {0};
	va_list	       	arg_list;

	if( !__laus_active ) {
	  return;
	}

	va_start(arg_list, fmt);
	vsnprintf(buffer, sizeof(buffer), fmt, arg_list);
	va_end(arg_list);

	if( laus_log( tag, "%s", buffer ) < 0 ) {
		laus_help_errmsg( "laus_log", errno );
	}
#endif
}
